Index: webrtc/media/engine/webrtcvoiceengine.h |
diff --git a/webrtc/media/engine/webrtcvoiceengine.h b/webrtc/media/engine/webrtcvoiceengine.h |
index 162abd157e61d652a4f80a8c6211330f7368011a..5b435348e65e97d0c50d52ac06bc7e044b1f9f4c 100644 |
--- a/webrtc/media/engine/webrtcvoiceengine.h |
+++ b/webrtc/media/engine/webrtcvoiceengine.h |
@@ -121,13 +121,14 @@ class WebRtcVoiceEngine final : public webrtc::TraceCallback { |
bool is_dumping_aec_ = false; |
webrtc::AgcConfig default_agc_config_; |
// Cache received extended_filter_aec, delay_agnostic_aec and experimental_ns |
// values, and apply them in case they are missing in the audio options. We |
// need to do this because SetExtraOptions() will revert to defaults for |
// options which are not provided. |
rtc::Optional<bool> extended_filter_aec_; |
rtc::Optional<bool> delay_agnostic_aec_; |
rtc::Optional<bool> experimental_ns_; |
+ rtc::Optional<bool> intelligibility_enhancer_; |
RTC_DISALLOW_IMPLICIT_CONSTRUCTORS(WebRtcVoiceEngine); |
}; |
@@ -121,13 +121,14 @@ class WebRtcVoiceEngine final : public webrtc::TraceCallback { |
bool is_dumping_aec_ = false; |
webrtc::AgcConfig default_agc_config_; |
- // Cache received extended_filter_aec, delay_agnostic_aec and experimental_ns |
- // values, and apply them in case they are missing in the audio options. We |
- // need to do this because SetExtraOptions() will revert to defaults for |
- // options which are not provided. |
+ // Cache received extended_filter_aec, delay_agnostic_aec, experimental_ns and |
+ // intelligibility_enhancer values, and apply them in case they are missing |
+ // in the audio options. We need to do this because SetExtraOptions() will |
+ // revert to defaults for options which are not provided. |
rtc::Optional<bool> extended_filter_aec_; |
rtc::Optional<bool> delay_agnostic_aec_; |